# SageWorks Blogs
!!! tip inline end "Just Getting Started?"
    The SageWorks Blogs is a great way to see what's possible with SageWorks. Also if you're ready to just in the [API Classes](../api_classes/overview.md) will give you details on the SageWorks ML Pipeline Classes.

## Blogs

- **[AqSol Residual Analysis](residual_analysis.md):** If this Blog we'll look at the popular AqSol compound solubility dataset and walk backward through the ML pipeline by starting with model residuals and backtracking to the features and input data.


!!! note "Examples"
    All of the SageWorks Examples are in the Sageworks Repository under the `examples/` directory. For a full code listing of any example please visit our [SageWorks Examples](https://github.com/SuperCowPowers/sageworks/blob/main/examples)
